NSDictionary extension type

NSDictionary

on
Implemented types
Implementers
Available extensions

Constructors

NSDictionary()
Returns a new instance of NSDictionary constructed with the default new method.
NSDictionary.as(ObjCObject other)
Constructs a NSDictionary that points to the same underlying object as other.
NSDictionary.fromPointer(Pointer<ObjCObjectImpl> other, {bool retain = false, bool release = false})
Constructs a NSDictionary that wraps the given raw object pointer.

Properties

allKeys → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

allKeys
no setter
allValues → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

allValues
no setter
count → int

Available on NSDictionary, provided by the NSDictionary$Methods extension

count
no setter
debugDescription → NSString

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

debugDescription
no setter
description → NSString

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

description
no setter
description$1 → NSString

Available on NSDictionary, provided by the NSExtendedDictionary extension

description
no setter
descriptionInStringsFileFormat → NSString

Available on NSDictionary, provided by the NSExtendedDictionary extension

descriptionInStringsFileFormat
no setter
hash → int

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

hash
no setter
hashCode → int
The hash code for this object.
no setterinherited
isProxy → bool

Available on NSObject, provided by the NSObject$Methods extension

isProxy
no setter
object$ → ObjCObject
final
ref → ObjCObjectRef
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
superclass → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

superclass
no setter

Methods

addObserver(Observer observer, {required NSString forKeyPath, int options = NSKeyValueObservingOptions.NSKeyValueObservingOptionNew, Pointer<Void>? context}) → Observation

Available on NSObject, provided by the Observed extension

Registers the Observer to receive KVO notifications for the key path relative to this NSObject.
allKeysForObject(ObjCObject anObject) → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

allKeysForObject:
asDart() → Map<NSCopying, ObjCObject>

Available on NSDictionary, provided by the NSDictionaryToAdapter extension

Wraps this NSDictionary in an adapter that implements an immutable Map.
autorelease() → NSObjectProtocol

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

autorelease
class$() → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

class
conformsToProtocol(Protocol aProtocol) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

conformsToProtocol:
copy() → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

copy
copyWithZone(Pointer<NSZone> zone) → ObjCObject

Available on NSCopying, provided by the NSCopying$Methods extension

copyWithZone:
countByEnumeratingWithState(Pointer<NSFastEnumerationState> state, {required Pointer<Pointer<ObjCObjectImpl>> objects, required DartNSUInteger count}) → DartNSUInteger

Available on NSDictionary, provided by the NSDictionary$Methods extension

countByEnumeratingWithState:objects:count:
countByEnumeratingWithState(Pointer<NSFastEnumerationState> state, {required Pointer<Pointer<ObjCObjectImpl>> objects, required DartNSUInteger count}) → DartNSUInteger

Available on NSFastEnumeration, provided by the NSFastEnumeration$Methods extension

countByEnumeratingWithState:objects:count:
dealloc() → void

Available on NSObject, provided by the NSObject$Methods extension

dealloc
descriptionWithLocale(ObjCObject? locale) → NSString

Available on NSDictionary, provided by the NSExtendedDictionary extension

descriptionWithLocale:
descriptionWithLocale$1(ObjCObject? locale, {required DartNSUInteger indent}) → NSString

Available on NSDictionary, provided by the NSExtendedDictionary extension

descriptionWithLocale:indent:
doesNotRecognizeSelector(Pointer<ObjCSelector> aSelector) → void

Available on NSObject, provided by the NSObject$Methods extension

doesNotRecognizeSelector:
encodeWithCoder(NSCoder coder) → void

Available on NSCoding, provided by the NSCoding$Methods extension

encodeWithCoder:
encodeWithCoder(NSCoder coder) → void

Available on NSDictionary, provided by the NSDictionary$Methods extension

encodeWithCoder:
encodeWithCoder(NSCoder coder) → void

Available on NSSecureCoding, provided by the NSSecureCoding$Methods extension

encodeWithCoder:
enumerateKeysAndObjectsUsingBlock(ObjCBlock<Void Function(Pointer<ObjCObjectImpl>, Pointer<ObjCObjectImpl>, Pointer<Bool>)> block) → void

Available on NSDictionary, provided by the NSExtendedDictionary extension

enumerateKeysAndObjectsUsingBlock:
enumerateKeysAndObjectsWithOptions(DartNSUInteger opts, {required ObjCBlock<Void Function(Pointer<ObjCObjectImpl>, Pointer<ObjCObjectImpl>, Pointer<Bool>)> usingBlock}) → void

Available on NSDictionary, provided by the NSExtendedDictionary extension

enumerateKeysAndObjectsWithOptions:usingBlock:
forwardingTargetForSelector(Pointer<ObjCSelector> aSelector) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

forwardingTargetForSelector:
forwardInvocation(NSInvocation anInvocation) → void

Available on NSObject, provided by the NSObject$Methods extension

forwardInvocation:
getObjects(Pointer<Pointer<ObjCObjectImpl>> objects, {required Pointer<Pointer<ObjCObjectImpl>> andKeys, required DartNSUInteger count}) → void

Available on NSDictionary, provided by the NSExtendedDictionary extension

getObjects:andKeys:count:
init() → NSDictionary

Available on NSDictionary, provided by the NSDictionary$Methods extension

init
init() → NSObject

Available on NSObject, provided by the NSObject$Methods extension

init
initWithCoder(NSCoder coder) → NSCoding?

Available on NSCoding, provided by the NSCoding$Methods extension

initWithCoder:
initWithCoder(NSCoder coder) → NSDictionary?

Available on NSDictionary, provided by the NSDictionary$Methods extension

initWithCoder:
initWithCoder(NSCoder coder) → NSSecureCoding?

Available on NSSecureCoding, provided by the NSSecureCoding$Methods extension

initWithCoder:
initWithContentsOfURL(NSURL url) → NSDictionary?

Available on NSDictionary, provided by the NSDictionaryCreation extension

initWithContentsOfURL:error:
initWithDictionary(NSDictionary otherDictionary) → NSDictionary

Available on NSDictionary, provided by the NSDictionary$Methods extension

initWithDictionary:
initWithDictionary$1(NSDictionary otherDictionary, {required bool copyItems}) → NSDictionary

Available on NSDictionary, provided by the NSDictionary$Methods extension

initWithDictionary:copyItems:
initWithObjects(NSArray objects, {required NSArray forKeys}) → NSDictionary

Available on NSDictionary, provided by the NSDictionary$Methods extension

initWithObjects:forKeys:
initWithObjects$1(Pointer<Pointer<ObjCObjectImpl>> objects, {required Pointer<Pointer<ObjCObjectImpl>> forKeys, required DartNSUInteger count}) → NSDictionary

Available on NSDictionary, provided by the NSDictionary$Methods extension

initWithObjects:forKeys:count:
initWithObjectsAndKeys(ObjCObject firstObject) → NSDictionary

Available on NSDictionary, provided by the NSDictionary$Methods extension

initWithObjectsAndKeys:
isEqual(ObjCObject object) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isEqual:
isEqual(ObjCObject object) → bool

Available on NSObject, provided by the NSObject$Methods extension

isEqual:
isEqualToDictionary(NSDictionary otherDictionary) → bool

Available on NSDictionary, provided by the NSExtendedDictionary extension

isEqualToDictionary:
isKindOfClass(ObjCObject aClass) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isKindOfClass:
isKindOfClass(ObjCObject aClass) → bool

Available on NSObject, provided by the NSObject$Methods extension

isKindOfClass:
isMemberOfClass(ObjCObject aClass) → bool

Available on NSObject, provided by the NSObject$Methods extension

isMemberOfClass:
isMemberOfClass(ObjCObject aClass) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isMemberOfClass:
isProxy() → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isProxy
keyEnumerator() → NSEnumerator

Available on NSDictionary, provided by the NSDictionary$Methods extension

keyEnumerator
keysOfEntriesPassingTest(ObjCBlock<Bool Function(Pointer<ObjCObjectImpl>, Pointer<ObjCObjectImpl>, Pointer<Bool>)> predicate) → NSSet

Available on NSDictionary, provided by the NSExtendedDictionary extension

keysOfEntriesPassingTest:
keysOfEntriesWithOptions(DartNSUInteger opts, {required ObjCBlock<Bool Function(Pointer<ObjCObjectImpl>, Pointer<ObjCObjectImpl>, Pointer<Bool>)> passingTest}) → NSSet

Available on NSDictionary, provided by the NSExtendedDictionary extension

keysOfEntriesWithOptions:passingTest:
keysSortedByValueUsingComparator(ObjCBlock<Long Function(Pointer<ObjCObjectImpl>, Pointer<ObjCObjectImpl>)> cmptr) → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

keysSortedByValueUsingComparator:
keysSortedByValueUsingSelector(Pointer<ObjCSelector> comparator) → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

keysSortedByValueUsingSelector:
keysSortedByValueWithOptions(DartNSUInteger opts, {required ObjCBlock<Long Function(Pointer<ObjCObjectImpl>, Pointer<ObjCObjectImpl>)> usingComparator}) → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

keysSortedByValueWithOptions:usingComparator:
methodForSelector(Pointer<ObjCSelector> aSelector) → Pointer<NativeFunction<Void Function()>>

Available on NSObject, provided by the NSObject$Methods extension

methodForSelector:
methodSignatureForSelector(Pointer<ObjCSelector> aSelector) → NSMethodSignature

Available on NSObject, provided by the NSObject$Methods extension

methodSignatureForSelector:
mutableCopy() → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

mutableCopy
mutableCopyWithZone(Pointer<NSZone> zone) → ObjCObject

Available on NSMutableCopying, provided by the NSMutableCopying$Methods extension

mutableCopyWithZone:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objectEnumerator() → NSEnumerator

Available on NSDictionary, provided by the NSExtendedDictionary extension

objectEnumerator
objectForKey(ObjCObject aKey) → ObjCObject?

Available on NSDictionary, provided by the NSDictionary$Methods extension

objectForKey:
objectForKeyedSubscript(ObjCObject key) → ObjCObject?

Available on NSDictionary, provided by the NSExtendedDictionary extension

objectForKeyedSubscript:
objectsForKeys(NSArray keys, {required ObjCObject notFoundMarker}) → NSArray

Available on NSDictionary, provided by the NSExtendedDictionary extension

objectsForKeys:notFoundMarker:
performSelector(Pointer<ObjCSelector> aSelector) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

performSelector:
performSelector(Pointer<ObjCSelector> aSelector) → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

performSelector:
performSelector$1(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject}) → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

performSelector:withObject:
performSelector$1(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject}) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

performSelector:withObject:
performSelector$2(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject, required ObjCObject withObject$1}) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

performSelector:withObject:withObject:
performSelector$2(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject, required ObjCObject withObject$1}) → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

performSelector:withObject:withObject:
release() → void

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

release
respondsToSelector(Pointer<ObjCSelector> sel) → bool

Available on ObjCObject, provided by the RespondsToSelector extension

respondsToSelector(Pointer<ObjCSelector> aSelector) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

respondsToSelector:
retain() → NSObjectProtocol

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

retain
retainCount() → int

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

retainCount
self() → NSObjectProtocol

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

self
toDartMap({Object convertOther(ObjCObject) = _defaultDartConverter}) → Map<Object, Object>

Available on NSDictionary, provided by the NSDictionaryToDartMap extension

Deep converts this NSDictionary to a Dart Map.
toString() → String
A string representation of this object.
inherited
writeToURL(NSURL url) → bool

Available on NSDictionary, provided by the NSExtendedDictionary extension

writeToURL:error:
zone() → Pointer<NSZone>

Available on NSObject, provided by the NSObject$Methods extension

zone
zone() → Pointer<NSZone>

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

zone

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alloc() → NSDictionary
alloc
allocWithZone(Pointer<NSZone> zone) → NSDictionary
allocWithZone:
dictionary() → NSDictionary
dictionary
dictionaryWithDictionary(NSDictionary dict) → NSDictionary
dictionaryWithDictionary:
dictionaryWithObject(ObjCObject object, {required NSCopying forKey}) → NSDictionary
dictionaryWithObject:forKey:
dictionaryWithObjects(NSArray objects, {required NSArray forKeys}) → NSDictionary
dictionaryWithObjects:forKeys:
dictionaryWithObjects$1(Pointer<Pointer<ObjCObjectImpl>> objects, {required Pointer<Pointer<ObjCObjectImpl>> forKeys, required DartNSUInteger count}) → NSDictionary
dictionaryWithObjects:forKeys:count:
dictionaryWithObjectsAndKeys(ObjCObject firstObject) → NSDictionary
dictionaryWithObjectsAndKeys:
fromEntries(Iterable<MapEntry<NSCopying, ObjCObject>> entries) → NSDictionary
Creates a NSDictionary from entries.
getSupportsSecureCoding() → bool
supportsSecureCoding
isA(ObjCObject? obj) → bool
Returns whether obj is an instance of NSDictionary.
new$() → NSDictionary
new
of(Map<NSCopying, ObjCObject> other) → NSDictionary
Creates a NSDictionary from other.