NSSecureCoding extension type

NSSecureCoding

on
Implemented types
Implementers
Available extensions

Constructors

NSSecureCoding.as(ObjCObject other)
Constructs a NSSecureCoding that points to the same underlying object as other.
NSSecureCoding.fromPointer(Pointer<ObjCObjectImpl> other, {bool retain = false, bool release = false})
Constructs a NSSecureCoding that wraps the given raw object pointer.

Properties

hashCode → int
The hash code for this object.
no setterinherited
object$ → ObjCObject
final
ref → ObjCObjectRef
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeWithCoder(NSCoder coder) → void

Available on NSCoding, provided by the NSCoding$Methods extension

encodeWithCoder:
encodeWithCoder(NSCoder coder) → void

Available on NSSecureCoding, provided by the NSSecureCoding$Methods extension

encodeWithCoder:
initWithCoder(NSCoder coder) → NSCoding?

Available on NSCoding, provided by the NSCoding$Methods extension

initWithCoder:
initWithCoder(NSCoder coder) → NSSecureCoding?

Available on NSSecureCoding, provided by the NSSecureCoding$Methods extension

initWithCoder:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
respondsToSelector(Pointer<ObjCSelector> sel) → bool

Available on ObjCObject, provided by the RespondsToSelector extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

conformsTo(ObjCObject obj) → bool
Returns whether obj is an instance of NSSecureCoding.