parameterString property

  1. @Deprecated('The parameterString method is deprecated. Post deprecation for applications linked with or after the macOS 10.15, and for all iOS, watchOS, and tvOS applications, parameterString will always return nil, and the path method will return the complete path including the semicolon separator and params component if the URL string contains them.')
NSString? get parameterString

iOS: introduced 2.0.0, deprecated 13.0.0 macOS: introduced 10.2.0, deprecated 10.15.0

Implementation

@Deprecated(
  'The parameterString method is deprecated. Post deprecation for applications linked with or after the macOS 10.15, and for all iOS, watchOS, and tvOS applications, parameterString will always return nil, and the path method will return the complete path including the semicolon separator and params component if the URL string contains them.',
)
NSString? get parameterString {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal(
    'NSURL.parameterString',
    iOS: (false, (2, 0, 0)),
    macOS: (false, (10, 2, 0)),
  );
  final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_parameterString);
  return $ret.address == 0
      ? null
      : NSString.fromPointer($ret, retain: true, release: true);
}