NSURL extension type

NSURL

on
Implemented types
Available extensions

Constructors

NSURL()
Returns a new instance of NSURL constructed with the default new method.
NSURL.as(ObjCObject other)
Constructs a NSURL that points to the same underlying object as other.
NSURL.fromPointer(Pointer<ObjCObjectImpl> other, {bool retain = false, bool release = false})
Constructs a NSURL that wraps the given raw object pointer.

Properties

absoluteString → NSString?

Available on NSURL, provided by the NSURL$Methods extension

absoluteString
no setter
absoluteURL → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

absoluteURL
no setter
baseURL → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

baseURL
no setter
dataRepresentation → NSData

Available on NSURL, provided by the NSURL$Methods extension

dataRepresentation
no setter
debugDescription → NSString

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

debugDescription
no setter
description → NSString

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

description
no setter
filePathURL → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

filePathURL
no setter
fileSystemRepresentation → Pointer<Char>

Available on NSURL, provided by the NSURL$Methods extension

fileSystemRepresentation
no setter
fragment → NSString?

Available on NSURL, provided by the NSURL$Methods extension

fragment
no setter
hasDirectoryPath → bool

Available on NSURL, provided by the NSURL$Methods extension

hasDirectoryPath
no setter
hash → int

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

hash
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → NSString?

Available on NSURL, provided by the NSURL$Methods extension

host
no setter
isFileURL → bool

Available on NSURL, provided by the NSURL$Methods extension

isFileURL
no setter
isProxy → bool

Available on NSObject, provided by the NSObject$Methods extension

isProxy
no setter
isProxy → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isProxy
no setter
object$ → ObjCObject
final
parameterString → NSString?

Available on NSURL, provided by the NSURL$Methods extension

iOS: introduced 2.0.0, deprecated 13.0.0 macOS: introduced 10.2.0, deprecated 10.15.0
no setter
password → NSString?

Available on NSURL, provided by the NSURL$Methods extension

password
no setter
path → NSString?

Available on NSURL, provided by the NSURL$Methods extension

path
no setter
port → NSNumber?

Available on NSURL, provided by the NSURL$Methods extension

port
no setter
query → NSString?

Available on NSURL, provided by the NSURL$Methods extension

query
no setter
ref → ObjCObjectRef
finalinherited
relativePath → NSString?

Available on NSURL, provided by the NSURL$Methods extension

relativePath
no setter
relativeString → NSString

Available on NSURL, provided by the NSURL$Methods extension

relativeString
no setter
resourceSpecifier → NSString?

Available on NSURL, provided by the NSURL$Methods extension

resourceSpecifier
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → NSString?

Available on NSURL, provided by the NSURL$Methods extension

scheme
no setter
standardizedURL → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

standardizedURL
no setter
superclass → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

superclass
no setter
user → NSString?

Available on NSURL, provided by the NSURL$Methods extension

user
no setter

Methods

addObserver(Observer observer, {required NSString forKeyPath, int options = NSKeyValueObservingOptions.NSKeyValueObservingOptionNew, Pointer<Void>? context}) → Observation

Available on NSObject, provided by the Observed extension

Registers the Observer to receive KVO notifications for the key path relative to this NSObject.
autorelease() → NSObjectProtocol

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

autorelease
bookmarkDataWithOptions(DartNSUInteger options, {NSArray? includingResourceValuesForKeys, NSURL? relativeToURL}) → NSData?

Available on NSURL, provided by the NSURL$Methods extension

bookmarkDataWithOptions:includingResourceValuesForKeys:relativeToURL:error:
class$() → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

class
conformsToProtocol(Protocol aProtocol) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

conformsToProtocol:
copy() → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

copy
copyWithZone(Pointer<NSZone> zone) → ObjCObject

Available on NSCopying, provided by the NSCopying$Methods extension

copyWithZone:
dealloc() → void

Available on NSObject, provided by the NSObject$Methods extension

dealloc
doesNotRecognizeSelector(Pointer<ObjCSelector> aSelector) → void

Available on NSObject, provided by the NSObject$Methods extension

doesNotRecognizeSelector:
encodeWithCoder(NSCoder coder) → void

Available on NSSecureCoding, provided by the NSSecureCoding$Methods extension

encodeWithCoder:
encodeWithCoder(NSCoder coder) → void

Available on NSCoding, provided by the NSCoding$Methods extension

encodeWithCoder:
encodeWithCoder(NSCoder coder) → void

Available on NSURL, provided by the NSURL$Methods extension

encodeWithCoder:
fileReferenceURL() → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

fileReferenceURL
forwardingTargetForSelector(Pointer<ObjCSelector> aSelector) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

forwardingTargetForSelector:
forwardInvocation(NSInvocation anInvocation) → void

Available on NSObject, provided by the NSObject$Methods extension

forwardInvocation:
getFileSystemRepresentation(Pointer<Char> buffer, {required DartNSUInteger maxLength}) → bool

Available on NSURL, provided by the NSURL$Methods extension

getFileSystemRepresentation:maxLength:
getResourceValue(Pointer<Pointer<ObjCObjectImpl>> value, {required NSString forKey}) → bool

Available on NSURL, provided by the NSURL$Methods extension

getResourceValue:forKey:error:
init() → NSObject

Available on NSObject, provided by the NSObject$Methods extension

init
init() → NSURL

Available on NSURL, provided by the NSURL$Methods extension

init
initAbsoluteURLWithDataRepresentation(NSData data, {NSURL? relativeToURL}) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initAbsoluteURLWithDataRepresentation:relativeToURL:
initByResolvingBookmarkData(NSData bookmarkData, {required DartNSUInteger options, NSURL? relativeToURL, required Pointer<Bool> bookmarkDataIsStale}) → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

initByResolvingBookmarkData:options:relativeToURL:bookmarkDataIsStale:error:
initFileURLWithFileSystemRepresentation(Pointer<Char> path, {required bool isDirectory, NSURL? relativeToURL}) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initFileURLWithFileSystemRepresentation:isDirectory:relativeToURL:
initFileURLWithPath(NSString path) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initFileURLWithPath:
initFileURLWithPath$1(NSString path, {required bool isDirectory}) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initFileURLWithPath:isDirectory:
initFileURLWithPath$2(NSString path, {required bool isDirectory, NSURL? relativeToURL}) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initFileURLWithPath:isDirectory:relativeToURL:
initFileURLWithPath$3(NSString path, {NSURL? relativeToURL}) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initFileURLWithPath:relativeToURL:
initWithCoder(NSCoder coder) → NSCoding?

Available on NSCoding, provided by the NSCoding$Methods extension

initWithCoder:
initWithCoder(NSCoder coder) → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

initWithCoder:
initWithCoder(NSCoder coder) → NSSecureCoding?

Available on NSSecureCoding, provided by the NSSecureCoding$Methods extension

initWithCoder:
initWithDataRepresentation(NSData data, {NSURL? relativeToURL}) → NSURL

Available on NSURL, provided by the NSURL$Methods extension

initWithDataRepresentation:relativeToURL:
initWithString(NSString URLString) → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

initWithString:
initWithString$1(NSString URLString, {required bool encodingInvalidCharacters}) → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

initWithString:encodingInvalidCharacters:
initWithString$2(NSString URLString, {NSURL? relativeToURL}) → NSURL?

Available on NSURL, provided by the NSURL$Methods extension

initWithString:relativeToURL:
isEqual(ObjCObject object) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isEqual:
isEqual(ObjCObject object) → bool

Available on NSObject, provided by the NSObject$Methods extension

isEqual:
isFileReferenceURL() → bool

Available on NSURL, provided by the NSURL$Methods extension

isFileReferenceURL
isKindOfClass(ObjCObject aClass) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isKindOfClass:
isKindOfClass(ObjCObject aClass) → bool

Available on NSObject, provided by the NSObject$Methods extension

isKindOfClass:
isMemberOfClass(ObjCObject aClass) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

isMemberOfClass:
isMemberOfClass(ObjCObject aClass) → bool

Available on NSObject, provided by the NSObject$Methods extension

isMemberOfClass:
methodForSelector(Pointer<ObjCSelector> aSelector) → Pointer<NativeFunction<Void Function()>>

Available on NSObject, provided by the NSObject$Methods extension

methodForSelector:
methodSignatureForSelector(Pointer<ObjCSelector> aSelector) → NSMethodSignature

Available on NSObject, provided by the NSObject$Methods extension

methodSignatureForSelector:
mutableCopy() → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

mutableCopy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performSelector(Pointer<ObjCSelector> aSelector) → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

performSelector:
performSelector(Pointer<ObjCSelector> aSelector) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

performSelector:
performSelector$1(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject}) → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

performSelector:withObject:
performSelector$1(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject}) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

performSelector:withObject:
performSelector$2(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject, required ObjCObject withObject$1}) → ObjCObject

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

performSelector:withObject:withObject:
performSelector$2(Pointer<ObjCSelector> aSelector, {required ObjCObject withObject, required ObjCObject withObject$1}) → ObjCObject

Available on NSObject, provided by the NSObject$Methods extension

performSelector:withObject:withObject:
release() → void

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

release
removeAllCachedResourceValues() → void

Available on NSURL, provided by the NSURL$Methods extension

removeAllCachedResourceValues
removeCachedResourceValueForKey(NSString key) → void

Available on NSURL, provided by the NSURL$Methods extension

removeCachedResourceValueForKey:
resourceValuesForKeys(NSArray keys) → NSDictionary?

Available on NSURL, provided by the NSURL$Methods extension

resourceValuesForKeys:error:
respondsToSelector(Pointer<ObjCSelector> aSelector) → bool

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

respondsToSelector:
respondsToSelector(Pointer<ObjCSelector> sel) → bool

Available on ObjCObject, provided by the RespondsToSelector extension

retain() → NSObjectProtocol

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

retain
retainCount() → int

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

retainCount
self() → NSObjectProtocol

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

self
setResourceValue(ObjCObject? value, {required NSString forKey}) → bool

Available on NSURL, provided by the NSURL$Methods extension

setResourceValue:forKey:error:
setResourceValues(NSDictionary keyedValues) → bool

Available on NSURL, provided by the NSURL$Methods extension

setResourceValues:error:
setTemporaryResourceValue(ObjCObject? value, {required NSString forKey}) → void

Available on NSURL, provided by the NSURL$Methods extension

setTemporaryResourceValue:forKey:
startAccessingSecurityScopedResource() → bool

Available on NSURL, provided by the NSURL$Methods extension

startAccessingSecurityScopedResource
stopAccessingSecurityScopedResource() → void

Available on NSURL, provided by the NSURL$Methods extension

stopAccessingSecurityScopedResource
toString() → String
A string representation of this object.
inherited
zone() → Pointer<NSZone>

Available on NSObjectProtocol, provided by the NSObjectProtocol$Methods extension

zone
zone() → Pointer<NSZone>

Available on NSObject, provided by the NSObject$Methods extension

zone

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

absoluteURLWithDataRepresentation(NSData data, {NSURL? relativeToURL}) → NSURL
absoluteURLWithDataRepresentation:relativeToURL:
alloc() → NSURL
alloc
allocWithZone(Pointer<NSZone> zone) → NSURL
allocWithZone:
bookmarkDataWithContentsOfURL(NSURL bookmarkFileURL) → NSData?
bookmarkDataWithContentsOfURL:error:
fileURLWithFileSystemRepresentation(Pointer<Char> path, {required bool isDirectory, NSURL? relativeToURL}) → NSURL
fileURLWithFileSystemRepresentation:isDirectory:relativeToURL:
fileURLWithPath(NSString path) → NSURL
fileURLWithPath:
fileURLWithPath$1(NSString path, {required bool isDirectory}) → NSURL
fileURLWithPath:isDirectory:
fileURLWithPath$2(NSString path, {required bool isDirectory, NSURL? relativeToURL}) → NSURL
fileURLWithPath:isDirectory:relativeToURL:
fileURLWithPath$3(NSString path, {NSURL? relativeToURL}) → NSURL
fileURLWithPath:relativeToURL:
getSupportsSecureCoding() → bool
supportsSecureCoding
isA(ObjCObject? obj) → bool
Returns whether obj is an instance of NSURL.
new$() → NSURL
new
resourceValuesForKeys$1(NSArray keys, {required NSData fromBookmarkData}) → NSDictionary?
resourceValuesForKeys:fromBookmarkData:
URLByResolvingAliasFileAtURL(NSURL url, {required DartNSUInteger options}) → NSURL?
URLByResolvingAliasFileAtURL:options:error:
URLByResolvingBookmarkData(NSData bookmarkData, {required DartNSUInteger options, NSURL? relativeToURL, required Pointer<Bool> bookmarkDataIsStale}) → NSURL?
URLByResolvingBookmarkData:options:relativeToURL:bookmarkDataIsStale:error:
URLWithDataRepresentation(NSData data, {NSURL? relativeToURL}) → NSURL
URLWithDataRepresentation:relativeToURL:
URLWithString(NSString URLString) → NSURL?
URLWithString:
URLWithString$1(NSString URLString, {required bool encodingInvalidCharacters}) → NSURL?
URLWithString:encodingInvalidCharacters:
URLWithString$2(NSString URLString, {NSURL? relativeToURL}) → NSURL?
URLWithString:relativeToURL:
writeBookmarkData(NSData bookmarkData, {required NSURL toURL, required DartNSUInteger options}) → bool
writeBookmarkData:toURL:options:error: