ObjCObject class

Base class for all Objective-C objects.

Implementers
Available extensions

Constructors

ObjCObject(ObjectPtr ptr, {required bool retain, required bool release})

Properties

hashCode → int
The hash code for this object.
no setterinherited
ref → ObjCObjectRef
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
respondsToSelector(Pointer<ObjCSelector> sel) → bool

Available on ObjCObject, provided by the RespondsToSelector extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited